=======
History
=======

2.1 (2020-06-11)
^^^^^^^^^^^^^^^^

* Drops Python 2.7 compatibility
* Uses importlib.resources to access resource files (requires Python 3.9 or installed package importlib_resources)

2.0 (2019-04-15)
^^^^^^^^^^^^^^^^

* Convert dials_data to a pytest plugin

1.0 (2019-02-16)
^^^^^^^^^^^^^^^^

* Add functions for forward-compatibility
* Enable new release process including automatic deployment of updates

0.6 (2019-02-15)
^^^^^^^^^^^^^^^^

* Added datasets blend_tutorial, thaumatin_i04

0.5 (2019-01-24)
^^^^^^^^^^^^^^^^

* Added documentation
* Added datasets fumarase, vmxi_thaumatin

0.4 (2019-01-11)
^^^^^^^^^^^^^^^^

* Beta release
* Added datasets insulin, pychef
* Automated generation of hashinfo files via Travis


0.3 (2019-01-09)
^^^^^^^^^^^^^^^^

* Dataset download mechanism
* Added dataset x4wide


0.2 (2019-01-08)
^^^^^^^^^^^^^^^^

* Alpha release
* Basic command line interface
* pytest fixture


0.1 (2018-11-02)
^^^^^^^^^^^^^^^^

* First automatic deployment and release on PyPI
